pub struct QueueCrank {
pub config: Pubkey,
pub fee: Pubkey,
pub pool: Pubkey,
pub queue: Pubkey,
pub system_program: Pubkey,
pub worker: Pubkey,
}Expand description
Generated client accounts for QueueCrank.
Fields
config: Pubkeyfee: Pubkeypool: Pubkeyqueue: Pubkeysystem_program: Pubkeyworker: PubkeyTrait Implementations
Sourceimpl BorshSerialize for QueueCrankwhere
Pubkey: BorshSerialize,
impl BorshSerialize for QueueCrankwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for QueueCrank
impl ToAccountMetas for QueueCrank
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for QueueCrank
impl RefUnwindSafe for QueueCrank
impl Send for QueueCrank
impl Sync for QueueCrank
impl Unpin for QueueCrank
impl UnsafeUnpin for QueueCrank
impl UnwindSafe for QueueCrank